@@ -19,6 +19,11 @@ if [ -f single-file-test ]; then
 	die $LINENO 'Shebang invocation produced binary in current directory'
 fi
 
+if ! { ${DUB} run --single issue103-single-file-package-w-dep.d --temp-build 2>&1 || true; } | grep -cF "To force a rebuild"; then
+	echo "Invocation triggered unnecessary rebuild."
+	exit 1
+fi
+
 if ${DUB} "issue103-single-file-package-error.d" 2> /dev/null; then
 	echo "Invalid package comment syntax did not trigger an error."
 	exit 1
