@@ -2,6 +2,9 @@
 
 . $(dirname "${BASH_SOURCE[0]}")/common.sh
 
+DUBPKGPATH=${DPATH+"$DPATH/dub/packages/dub"}
+DUBPKGPATH=${DUBPKGPATH:-"$HOME/.dub/packages/dub"}
+
 $DUB add-local "$CURR_DIR/version-spec/newfoo"
 $DUB add-local "$CURR_DIR/version-spec/oldfoo"
 
@@ -43,10 +46,10 @@ $DUB add-local "$CURR_DIR/version-spec/oldfoo"
 $DUB remove-local "$CURR_DIR/version-spec/newfoo"
 $DUB remove-local "$CURR_DIR/version-spec/oldfoo"
 
-$DUB fetch dub@1.9.0 && [ -d $HOME/.dub/packages/dub/1.9.0/dub ]
-$DUB fetch dub=1.10.0 && [ -d $HOME/.dub/packages/dub/1.10.0/dub ]
+$DUB fetch dub@1.9.0 && [ -d $DUBPKGPATH/1.9.0/dub ]
+$DUB fetch dub=1.10.0 && [ -d $DUBPKGPATH/1.10.0/dub ]
 $DUB remove dub@1.9.0
 $DUB remove dub=1.10.0
-if [ -d $HOME/.dub/packages/dub/1.9.0/dub ] || [ -d $HOME/.dub/packages/dub/1.10.0/dub ]; then
+if [ -d $DUBPKGPATH/1.9.0/dub ] || [ -d $DUBPKGPATH/1.10.0/dub ]; then
     die $LINENO 'Failed to remove specified versions'
 fi
